==> huaweicloudsdkecs-3.0.63-py2.py3-none-any.whl: huaweicloudsdkecs/v2/model/interface_attachable_quantity.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class InterfaceAttachableQuantity:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'free_nic': 'int'
    }

    attribute_map = {
        'free_nic': 'free_nic'
    }

    def __init__(self, free_nic=None):
        """InterfaceAttachableQuantity - a model defined in huaweicloud sdk"""
        
        

        self._free_nic = None
        self.discriminator = None

        if free_nic is not None:
            self.free_nic = free_nic

    @property
    def free_nic(self):
        """Gets the free_nic of this InterfaceAttachableQuantity.

        云服务器剩余可挂载网卡数量

        :return: The free_nic of this InterfaceAttachableQuantity.
        :rtype: int
        """
        return self._free_nic

    @free_nic.setter
    def free_nic(self, free_nic):
        """Sets the free_nic of this InterfaceAttachableQuantity.

        云服务器剩余可挂载网卡数量

        :param free_nic: The free_nic of this InterfaceAttachableQuantity.
        :type: int
        """
        self._free_nic = free_nic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InterfaceAttachableQuantity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkecs-3.0.94-py2.py3-none-any.whl: huaweicloudsdkecs/v2/model/interface_attachable_quantity.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class InterfaceAttachableQuantity:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'free_nic': 'int'
    }

    attribute_map = {
        'free_nic': 'free_nic'
    }

    def __init__(self, free_nic=None):
        """InterfaceAttachableQuantity

        The model defined in huaweicloud sdk

        :param free_nic: 云服务器剩余可挂载网卡数量
        :type free_nic: int
        """
        
        

        self._free_nic = None
        self.discriminator = None

        if free_nic is not None:
            self.free_nic = free_nic

    @property
    def free_nic(self):
        """Gets the free_nic of this InterfaceAttachableQuantity.

        云服务器剩余可挂载网卡数量

        :return: The free_nic of this InterfaceAttachableQuantity.
        :rtype: int
        """
        return self._free_nic

    @free_nic.setter
    def free_nic(self, free_nic):
        """Sets the free_nic of this InterfaceAttachableQuantity.

        云服务器剩余可挂载网卡数量

        :param free_nic: The free_nic of this InterfaceAttachableQuantity.
        :type free_nic: int
        """
        self._free_nic = free_nic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InterfaceAttachableQuantity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
